Reference documentation
=======================

Block diagonalization
---------------------
.. automodule:: pymablock
   :members:
   :show-inheritance:

Solvers of Sylvester equation
-----------------------------
.. automodule:: pymablock.block_diagonalization
   :members: solve_sylvester_diagonal, solve_sylvester_direct, solve_sylvester_KPM
   :show-inheritance:

Series
------
.. autoclass:: pymablock.series.BlockSeries

.. automodule:: pymablock.series
   :members: cauchy_dot_product
   :show-inheritance:

Linear algebra
--------------
.. automodule:: pymablock.linalg
   :members: direct_greens_function
   :show-inheritance:

Kernel polynomial method (KPM)
------------------------------
.. automodule:: pymablock.kpm
   :members: greens_function, rescale
   :show-inheritance:
